@@ -5,7 +5,7 @@ from __future__ import annotations
 from collections import defaultdict
 from configparser import ConfigParser
 from itertools import chain
-from typing import TYPE_CHECKING, Iterable, Iterator
+from typing import TYPE_CHECKING
 
 from tox.config.loader.ini import IniLoader
 from tox.config.loader.ini.factor import find_envs
@@ -15,10 +15,11 @@ from .api import Source
 from .ini_section import CORE, PKG_ENV_PREFIX, TEST_ENV_PREFIX, IniSection
 
 if TYPE_CHECKING:
+    from collections.abc import Iterable, Iterator
     from pathlib import Path
 
     from tox.config.loader.api import OverrideMap
-    from tox.config.sets import ConfigSet
+    from tox.config.sets import ConfigSet, CoreConfigSet
 
 
 class IniSource(Source):
@@ -74,9 +75,9 @@ class IniSource(Source):
     def get_tox_env_section(self, item: str) -> tuple[Section, list[str], list[str]]:  # noqa: PLR6301
         return IniSection.test_env(item), [TEST_ENV_PREFIX], [PKG_ENV_PREFIX]
 
-    def envs(self, core_config: ConfigSet) -> Iterator[str]:
+    def envs(self, core_conf: CoreConfigSet) -> Iterator[str]:
         seen = set()
-        for name in self._discover_tox_envs(core_config):
+        for name in self._discover_tox_envs(core_conf):
             if name not in seen:
                 seen.add(name)
                 yield name
