@@ -13,7 +13,7 @@ import warnings
 from contextlib import closing, contextmanager
 from pathlib import Path
 from types import ModuleType, TracebackType
-from typing import TYPE_CHECKING, Any, Callable, Iterator, Protocol, Sequence, cast
+from typing import TYPE_CHECKING, Any, Protocol, cast
 
 import pytest
 from _pytest.fixtures import SubRequest  # noqa: PLC2701
@@ -32,6 +32,7 @@ from tox.tox_env import api as tox_env_api
 from tox.tox_env.api import ToxEnv
 
 if TYPE_CHECKING:
+    from collections.abc import Callable, Iterator, Sequence
     from unittest.mock import MagicMock
 
     from pytest_mock import MockerFixture
@@ -53,7 +54,7 @@ if fs_supports_symlink():  # pragma: no cover # used to speed up test suite run
 
 
 @pytest.fixture(autouse=True)
-def ensure_logging_framework_not_altered() -> Iterator[None]:  # noqa: PT004
+def ensure_logging_framework_not_altered() -> Iterator[None]:
     before_handlers = list(LOGGER.handlers)
     yield
     LOGGER.handlers = before_handlers
@@ -82,7 +83,10 @@ def _disable_root_tox_py(request: SubRequest, mocker: MockerFixture) -> Iterator
 @contextmanager
 def check_os_environ() -> Iterator[None]:
     old = os.environ.copy()
-    to_clean = {k: os.environ.pop(k, None) for k in (ENV_VAR_KEY, "TOX_WORK_DIR", "PYTHONPATH", "COV_CORE_CONTEXT")}
+    to_clean = {
+        k: os.environ.pop(k, None)
+        for k in (ENV_VAR_KEY, "TOX_WORK_DIR", "PYTHONPATH", "COV_CORE_CONTEXT", "TOX_DISABLED_EXTERNAL_PLUGINS")
+    }
 
     yield
 
@@ -93,6 +97,7 @@ def check_os_environ() -> Iterator[None]:
     new = os.environ
     extra = {k: new[k] for k in set(new) - set(old)}
     extra.pop("PLAT", None)
+    extra.pop("TOX_DISABLED_EXTERNAL_PLUGINS", None)
     miss = {k: old[k] for k in set(old) - set(new)}
     diff = {
         f"{k} = {old[k]} vs {new[k]}" for k in set(old) & set(new) if old[k] != new[k] and not k.startswith("PYTEST_")
@@ -109,14 +114,14 @@ def check_os_environ() -> Iterator[None]:
 
 
 @pytest.fixture(autouse=True)
-def check_os_environ_stable(monkeypatch: pytest.MonkeyPatch) -> Iterator[None]:  # noqa: PT004
+def check_os_environ_stable(monkeypatch: pytest.MonkeyPatch) -> Iterator[None]:
     with check_os_environ():
         yield
         monkeypatch.undo()
 
 
 @pytest.fixture(autouse=True)
-def no_color(monkeypatch: pytest.MonkeyPatch, check_os_environ_stable: None) -> None:  # noqa: ARG001, PT004
+def no_color(monkeypatch: pytest.MonkeyPatch, check_os_environ_stable: None) -> None:  # noqa: ARG001
     monkeypatch.setenv("NO_COLOR", "yes")
 
 
@@ -160,7 +165,7 @@ class ToxProject:
                 msg = f"could not handle {at_path / key} with content {value!r}"  # pragma: no cover
                 raise TypeError(msg)  # pragma: no cover
 
-    def patch_execute(self, handle: Callable[[ExecuteRequest], int | None]) -> MagicMock:  # noqa: C901
+    def patch_execute(self, handle: Callable[[ExecuteRequest], int | None] | None = None) -> MagicMock:  # noqa: C901
         class MockExecute(Execute):
             def __init__(self, colored: bool, exit_code: int) -> None:  # noqa: FBT001
                 self.exit_code = exit_code
@@ -228,7 +233,7 @@ class ToxProject:
             request: ExecuteRequest,
             show: bool,  # noqa: FBT001
         ) -> Iterator[ExecuteStatus]:
-            exit_code = handle(request)
+            exit_code = 0 if handle is None else handle(request)
             if exit_code is not None:
                 executor = MockExecute(colored=executor._colored, exit_code=exit_code)  # noqa: SLF001
             with original_execute_call(self, executor, out_err, request, show) as status:
@@ -259,7 +264,10 @@ class ToxProject:
         finally:
             os.chdir(cur_dir)
 
-    def run(self, *args: str, from_cwd: Path | None = None) -> ToxRunOutcome:
+    def run(self, *args: str, from_cwd: Path | None = None, raise_on_config_fail: bool = True) -> ToxRunOutcome:
+        if raise_on_config_fail and args and args[0] in {"c", "config"}:
+            self.monkeypatch.setenv("_TOX_SHOW_CONFIG_RAISE", "1")
+
         with self.chdir(from_cwd):
             state = None
             self._capfd.readouterr()  # start with a clean state - drain
@@ -278,7 +286,6 @@ class ToxProject:
                 m.setenv("VIRTUALENV_SYMLINK_APP_DATA", "1")
                 m.setenv("VIRTUALENV_SYMLINKS", "1")
                 m.setenv("VIRTUALENV_PIP", "embed")
-                m.setenv("VIRTUALENV_WHEEL", "embed")
                 m.setenv("VIRTUALENV_SETUPTOOLS", "embed")
                 try:
                     tox_run(args)
@@ -288,14 +295,14 @@ class ToxProject:
                     msg = "exit code not set"
                     raise RuntimeError(msg)
             out, err = self._capfd.readouterr()
-            return ToxRunOutcome(args, self.path, cast(int, code), out, err, state)
+            return ToxRunOutcome(args, self.path, cast("int", code), out, err, state)
 
     def __repr__(self) -> str:
         return f"{type(self).__name__}(path={self.path}) at {id(self)}"
 
 
 @pytest.fixture(autouse=True, scope="session")
-def enable_pep517_backend_coverage() -> Iterator[None]:  # noqa: PT004
+def enable_pep517_backend_coverage() -> Iterator[None]:
     try:
         import coverage  # noqa: F401, PLC0415
     except ImportError:  # pragma: no cover
@@ -309,12 +316,13 @@ def enable_pep517_backend_coverage() -> Iterator[None]:  # noqa: PT004
         result.append("COV_*")
         return result
 
+    # monkey-patch to inject COV_* env vars, session-scoped so mocker unavailable
     previous = Pep517VirtualEnvPackager._default_pass_env  # noqa: SLF001
     try:
-        Pep517VirtualEnvPackager._default_pass_env = default_pass_env  # type: ignore[assignment]  # noqa: SLF001
+        Pep517VirtualEnvPackager._default_pass_env = default_pass_env  # noqa: SLF001  # ty: ignore[invalid-assignment]
         yield
     finally:
-        Pep517VirtualEnvPackager._default_pass_env = previous  # type: ignore[method-assign]  # noqa: SLF001
+        Pep517VirtualEnvPackager._default_pass_env = previous  # noqa: SLF001
 
 
 class ToxRunOutcome:
@@ -418,7 +426,7 @@ def init_fixture(
     mocker: MockerFixture,
 ) -> ToxProjectCreator:
     def _init(files: dict[str, Any], base: Path | None = None, prj_path: Path | None = None) -> ToxProject:
-        """Create tox  projects."""
+        """Create tox projects."""
         return ToxProject(files, base, prj_path or tmp_path / "p", capfd, monkeypatch, mocker)
 
     return _init
@@ -482,10 +490,10 @@ def pypi_server(tmp_path_factory: pytest.TempPathFactory) -> Iterator[IndexServe
 
 
 @pytest.fixture(scope="session")
-def _invalid_index_fake_port() -> int:  # noqa: PT005
+def _invalid_index_fake_port() -> int:
     with closing(socket.socket(socket.AF_INET, socket.SOCK_STREAM)) as socket_handler:
         socket_handler.bind(("", 0))
-        return cast(int, socket_handler.getsockname()[1])
+        return cast("int", socket_handler.getsockname()[1])
 
 
 @pytest.fixture(autouse=True)
@@ -516,7 +524,7 @@ def register_inline_plugin(mocker: MockerFixture, *args: Callable[..., Any]) ->
     assert caller_module is not None  # noqa: S101
     plugin = ModuleType(f"{caller_module.__name__}|{frame_info[3]}")
     plugin.__file__ = caller_module.__file__
-    plugin.__dict__.update({f.__name__: f for f in args})
+    plugin.__dict__.update({f.__name__: f for f in args})  # ty: ignore[unresolved-attribute] # https://github.com/astral-sh/ty/issues/1495
     mocker.patch("tox.plugin.manager.load_inline", return_value=plugin)
 
 
