@@ -65,7 +65,7 @@ def parallel_flags(
         type=parse_num_processes,
         default=default_parallel,
         metavar="VAL",
-        **({"nargs": "?"} if no_args else {}),  # type: ignore[arg-type] # type checker can't unroll it
+        **({"nargs": "?"} if no_args else {}),  # ty: ignore[invalid-argument-type] # https://github.com/astral-sh/ty/issues/2586
     )
     our.add_argument(
         "-o",
@@ -91,7 +91,7 @@ def run_parallel(state: State) -> int:
     option = state.conf.options
     return execute(
         state,
-        max_workers=None if option.parallel_no_spinner is True else option.parallel,
+        max_workers=auto_detect_cpus() if option.parallel == 0 else option.parallel,
         has_spinner=option.parallel_no_spinner is False and option.parallel_live is False,
         live=option.parallel_live,
     )
