@@ -6,7 +6,7 @@ from tox.execute.stream import SyncWrite
 
 
 def test_sync_write_repr() -> None:
-    sync_write = SyncWrite(name="a", target=None, color=Fore.RED)
+    sync_write = SyncWrite(name="a", target=None, color=str(Fore.RED))
     assert repr(sync_write) == f"SyncWrite(name='a', target=None, color={Fore.RED!r})"
 
 
