@@ -8,14 +8,15 @@ import pytest
 
 from tox.tox_env.python.package import WheelPackage
 from tox.tox_env.python.virtual_env.package.pyproject import Pep517VirtualEnvPackager
-from tox.tox_env.runner import RunToxEnv
 
 if TYPE_CHECKING:
     from pathlib import Path
 
     from tox.pytest import ToxProjectCreator
+    from tox.tox_env.runner import RunToxEnv
 
 
+@pytest.mark.slow
 @pytest.mark.integration
 def test_setuptools_package(
     tox_project: ToxProjectCreator,
@@ -35,7 +36,7 @@ def test_setuptools_package(
 
     outcome.assert_success()
     assert f"\ngreetings from demo_pkg_setuptools{os.linesep}" in outcome.out
-    tox_env = cast(RunToxEnv, outcome.state.envs["py"])
+    tox_env = cast("RunToxEnv", outcome.state.envs["py"])
 
     (package_env,) = list(tox_env.package_envs)
     assert isinstance(package_env, Pep517VirtualEnvPackager)
