@@ -25,7 +25,7 @@ def test_spinner(capfd: CaptureFixture, monkeypatch: MonkeyPatch) -> None:
             spin.stream.write("\n")
             spin.render_frame()
         spin.stream.write("\n")
-    out, err = capfd.readouterr()
+    out, _err = capfd.readouterr()
     lines = out.split("\n")
     expected = [f"\r{spin.CLEAR_LINE}\r{i} [0]" for i in spin.frames] + [
         f"\r{spin.CLEAR_LINE}\r{spin.frames[0]} [0]",
@@ -40,10 +40,11 @@ def test_spinner_disabled(capfd: CaptureFixture) -> None:
         spin.add("x")
         for _ in range(len(spin.frames)):
             spin.render_frame()
-        spin.finalize("x", "done", Fore.GREEN)
+        spin.finalize("x", "done", str(Fore.GREEN))
         spin.clear()
     out, err = capfd.readouterr()
-    assert out == f"{Fore.GREEN}x: done in 0 seconds{Fore.RESET}{os.linesep}", out
+    assert out.startswith(f"{Fore.GREEN}x: done in 0"), out
+    assert out.endswith(f" seconds{Fore.RESET}{os.linesep}"), out
     assert not err
 
 
@@ -65,7 +66,7 @@ def test_spinner_atty(capfd: CaptureFixture, monkeypatch: MonkeyPatch) -> None:
     monkeypatch.setattr(sys.stdout, "isatty", lambda: True)
     with spinner.Spinner(refresh_rate=100) as spin:
         spin.stream.write("\n")
-    out, err = capfd.readouterr()
+    out, _err = capfd.readouterr()
     lines = out.split("\n")
     posix = os.name == "posix"
     expected = [
